#!/bin/bash
COM_ERR=1
INSTALL_DIR=/opt/lcd
CONF_FILE=lcd.conf
LIB=lcd.lib


source $INSTALL_DIR/$CONF_FILE




if [ $# -eq 0 ]
then
	echo "Please type \"lcd.sh -help\" for a list of commands"
	exit 0
fi


if [ $1 = "-help" ]
then
	COM_ERR=0
	
	echo "List of commands"
	echo "=============="
	echo "-help"
	echo "-board_info"
	echo "-row_write row_num \"data\" "
	echo "-reset"
	echo "-backlight new_val"
	echo "-backlight_save"
	echo "-contrast new_val"
	echo "-contrast_save"
	echo "-read_conf"
	echo "-i2c_find"
	echo "-i2c_change_addr new_addr"
	echo "-sw_rev"
	echo "-fw_update file_name"
	echo " "


#Read Board information
elif [ $1 = "-board_info" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -board_info
	exit $?

#Write a row of the LCD
elif [ $1 = "-row_write" ]
then
	if [ $# -eq 3 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -row_write $2 "$3"
		exit $?
	else
		echo "ERROR: Expecting 2 arguments, row number and data in quotes, for example lcd.sh -row_write 1 \"abc\""
	fi



#Reset the LCD
elif [ $1 = "-reset" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -reset
	exit $?
	

#Adjust the backlight intensity
elif [ $1 = "-backlight" ]
then
	if [ $# -eq 2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -backlight $2
		exit $?
	else
		echo "ERROR: Expecting another argument, 0-160, for example lcd.sh -backlight 55"
	fi
	
#Save the backlight intensity to non volatile memory
elif [ $1 = "-backlight_save" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -backlight_save_flash
	exit $?
		

#Adjust the contrast
elif [ $1 = "-contrast" ]
then
	if [ $# -eq 2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -contrast $2
		exit $?
	else
		echo "ERROR: Expecting another argument, 0-160, for example lcd.sh -contrast 55"
	fi
	
#Save the contrast setting to non volatile memory
elif [ $1 = "-contrast_save" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -contrast_save_flash
	exit $?
	
#Read the .conf file
elif [ $1 = "-read_conf" ]
then
	COM_ERR=0
	cat $INSTALL_DIR/$CONF_FILE
	exit $?
				

#Scans the i2c bus to find the device
#Note: I2C address inside .conf file will be updated automatically 
elif [ $1 = "-i2c_find" ]
then
	COM_ERR=0
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -i2c_find
	
	tmp="$(printf '%x\n' $?)"
	
	if [ $tmp != ff ]
	then
		#Update .conf file
		echo "Updating I2C_ADDR variable inside $INSTALL_DIR/$CONF_FILE to $tmp"
		sudo sed -i "/I2C_ADDR=/c\I2C_ADDR=$tmp" $INSTALL_DIR/$CONF_FILE
	fi


#Change I2C address
#Note: I2C address inside .conf file will be updated automatically 
elif [ $1 = "-i2c_change_addr" ]
then
	if [ $# -eq 2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -i2c_change_addr $2
		
		if [ $? -eq 0 ]
		then
			#Update .conf file
			echo "Updating I2C_ADDR variable inside $CONF_FILE to $2"
			sudo sed -i "/I2C_ADDR=/c\I2C_ADDR=$2" $INSTALL_DIR/$CONF_FILE
		else
			echo "ERROR: Failed to update I2C address."
		fi
		
		exit $?
	else
		echo "ERROR: Expecting a hex number as an argument"
	fi

#Print software revision
elif [ $1 = "-sw_rev" ]
then
	sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -sw_rev
	exit $?
	
#Firmware update
elif [ $1 = "-fw_update" ]
then
	
	if [ $# -ne 2 ]
	then
		echo "Missing file name argument"
	elif [ -f $2 ]
	then
		COM_ERR=0
		sudo $INSTALL_DIR/$LIB -i2c_addr $I2C_ADDR -fw_update $2
	else
		echo "File doesn't exist"	
	fi
	
	exit $?


else
	echo "Unknown command($1), please use -help to see valid commands"
fi



if [ $COM_ERR = "1" ]
then
	echo "Error"
fi
	
	